[![Travis](https://api.travis-ci.com/wwood/argparse-manpage.svg?branch=bird_opinions)](https://travis-ci.org/wwood/argparse-manpage)

This code is a fork of https://github.com/praiskup/argparse-manpage with various
opinions introduced, to make it easier to use for the usual style of the
Woodcroft lab bird tools. See also
https://github.com/wwood/bird_tool_utils-python/

Also in contrast to upstream, the main aim of this repository is to provide code
that allows formatting of manpages at runtime, rather than at install-time.

# License

This work is released under the terms of the Apache License v2.0. See LICENSE
for details, and upstream repositories for author information.
